pub struct RpcVoteAccountInfo {
pub vote_pubkey: String,
pub node_pubkey: String,
pub activated_stake: u64,
pub commission: u8,
pub inflation_rewards_commission_bps: Option<u16>,
pub epoch_vote_account: bool,
pub epoch_credits: Vec<(u64, u64, u64)>,
pub last_vote: u64,
pub root_slot: u64,
}Fields
vote_pubkey: StringVote account address, as base-58 encoded string
node_pubkey: StringThe validator identity, as base-58 encoded string
activated_stake: u64The current stake, in lamports, delegated to this vote account
commission: u8An 8-bit unsigned integer used as a fraction (commission/100) for
rewards payout. Before SIMD-0291 activation, this is the native
commission value. After activation, this is derived from basis
points with: bps.div_ceil(100).min(255).
inflation_rewards_commission_bps: Option<u16>A 16-bit unsigned integer used as the raw basis points for rewards
payout. Before SIMD-0291 activation, this is derived from the
percentage commission: percent * 100. After activation, this is the
native basis points value stored in vote state.
Note: Field is None when querying a node that predates this field.
epoch_vote_account: boolWhether this account is staked for the current epoch
epoch_credits: Vec<(u64, u64, u64)>Latest history of earned credits for up to MAX_RPC_VOTE_ACCOUNT_INFO_EPOCH_CREDITS_HISTORY epochs
each tuple is (Epoch, credits, prev_credits)
last_vote: u64Most recent slot voted on by this vote account (0 if no votes exist)
root_slot: u64Current root slot for this vote account (0 if no root slot exists)